% Logistic equation: temporal and cobweb plots
%
% Computational Biology. Aderito Araujo. May 3, 2024
%
clear; clc; close all;
%% Parameters 
%
% Choose one r and one x0
% 
% Some examples 
% period 1
%r = 2.3;     % 0 <= r <= 4,   0.3,1.3,2.3,3,3.3,3.5,3.7,3.8,... 
%x0 = 0.2;    % Init. cond.: x0 = 0.2 for r=2.3 and x0 = 0.6 otherwise
% period 2
r = 3.1;      % 0 <= r <= 4,   0.3,1.3,2.3,3,3.3,3.5,3.7,3.8,... 
x0 = 0.6;     % Init. cond.: x0 = 0.2 for r=2.3 and x0 = 0.6 otherwise
% period 2
%r = 3.3;     % 0 <= r <= 4,   0.3,1.3,2.3,3,3.3,3.5,3.7,3.8,... 
%x0 = 0.6;    % Init. cond.: x0 = 0.2 for r=2.3 and x0 = 0.6 otherwise
% period 3
%r = 3.86;    % 0 <= r <= 4,   0.3,1.3,2.3,3,3.3,3.5,3.7,3.8,... 
%x0 = 0.6;    % Init. cond.: x0 = 0.2 for r=2.3 and x0 = 0.6 otherwise
% period 4
%r = 3.5;     % 0 <= r <= 4,   0.3,1.3,2.3,3,3.3,3.5,3.7,3.8,... 
%x0 = 0.6;    % Init. cond.: x0 = 0.2 for r=2.3 and x0 = 0.6 otherwise
% period 8
%r = 3.56;    % 0 <= r <= 4,   0.3,1.3,2.3,3,3.3,3.5,3.7,3.8,... 
%x0 = 0.6;    % Init. cond.: x0 = 0.2 for r=2.3 and x0 = 0.6 otherwise
%% Trajectory
f = @(x)r*x.*(1-x);  % Logistic
N = 20;              % Number of iterations

time = (0:1/N:1); 
x = zeros(size(time)); x(1) = x0;    
for ic=1:N
 x(ic+1) = f(x(ic));
end

%% Plots
subplot(211) % temporal plot
axis([min(x) max(x) 0 1])
plot(time,x,'-ko')
title(['Temporal evolution for r = ' num2str(r)]) ;
subplot(212) 
fplot(f,[0 1],'m'); hold on; % plot y = f(x)
fplot(@(x)x,[0 1],'b');      % plot y = x
str2 = ['Logistic function for r = ' num2str(r)];
set(gcf,'name',str2);

% Plot cobweb
 line([x(1) x(1)],[0 x(2)],'Color','k') 
 % plot(x(1), x(1),'ko');
  for ic=1:N-1
     line([x(ic) x(ic+1)],[x(ic+1) x(ic+1)],'Color','k'), pause(0.3);
  %   plot(x(ic+1), x(ic+1),'ko'), pause(0.3);
     line([x(ic+1) x(ic+1)],[x(ic+1) x(ic+2)],'Color','k'), pause(0.3);
     drawnow;
  end
 line([x(N) x(N+1)],[x(N+1) x(N+1)],'Color','k'), pause(0.3);
 plot(x(N+1), x(N+1),'m*');
 hold off;
 title(['Cobweb for r = ',num2str(r)]) ;


 