% Logistic: bifurcation diagram
%
% Computational Biology. Aderito Araujo. May 3, 2024
%
clear; clc; close all

%% Parameters

rmin = 2.8;   % min value for the bifurcation parameter r
rmax = 4;     % max value for the bifurcation parameter r
nstep = 500;  % number of steps

trans = 200;  % number of transient points
out = 200;    % number of output points
x0 = 0.66;    % inicial value x_0 for the fixed point method

rstep = (rmax-rmin)/nstep;

r = (rmin:rstep:rmax); % generate a line vector of r's

%% Iterations
f = @(r,x)r.*x.*(1-x);  % Logistic
x = x0 * ones( 1, size(r,2) );  % init. conditions (size r)
                                
hg = waitbar(0,'Phase 1...');
for i = 1:trans      % transient iterations for the given r's
   x = f(r,x);                 
   waitbar(i/trans);
end
close(hg) ;  

hg = waitbar(0,'Phase 2...');
y = []; % empty vector
for i = 1:out                 % output interations 
        x = f(r,x);      
        y = [y;x];            
   waitbar(i/out) ;                           
end
close(hg) ;                           

%% Plots

plot(r,y,'r.','markersize',1);
set(gcf,'name','Bifurcation diagram for the logistic equation');
axis([rmin rmax -0.1 1])
xlabel('Growth rate r');
ylabel('Population densitt');
title('Bifurcation diagram for the logistic equation');
grid on;
